#
# spec file for package stp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           stp
BuildRequires:  bison
%if 0%{?suse_version} > 1320
BuildRequires:  libboost_program_options-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  minisat-devel
BuildRequires:  ninja
BuildRequires:  python-devel
BuildRequires:  xz
Summary:        Constraint Solver
License:        MIT
Group:          Productivity/Scientific/Other
Version:        2.2+20161105
Release:        1.1
Url:            https://github.com/stp/stp/wiki
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.xz

%description
STP is an efficient decision procedure for the validity (or satisfiability) of
formulas from a quantifier-free many-sorted theory of fixed-width bitvectors
and (non-extensional) one-dimensional arrays. The functions in STP's input
language include concatenation, extraction, left/right shift, sign-extension,
unary minus, addition, multiplication, (signed) modulo/division, bitwise
Boolean operations, if-then-else terms, and array reads and writes. The
predicates in the language include equality and (signed) comparators between
bitvector terms.

%package -n libstp2_1
Summary:        Constraint Solver
Group:          System/Libraries

%description -n libstp2_1
STP is an efficient decision procedure for the validity (or satisfiability) of
formulas from a quantifier-free many-sorted theory of fixed-width bitvectors
and (non-extensional) one-dimensional arrays. The functions in STP's input
language include concatenation, extraction, left/right shift, sign-extension,
unary minus, addition, multiplication, (signed) modulo/division, bitwise
Boolean operations, if-then-else terms, and array reads and writes. The
predicates in the language include equality and (signed) comparators between
bitvector terms.

%package devel
Summary:        Devel files for stp
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}
%if 0%{?suse_version} > 1320
Requires:       libboost_program_options-devel
%else
Requires:       boost-devel
%endif
Requires:       libstp2_1 = %{version}
Requires:       minisat-devel

%description devel
Developmnet files for stp library.

%package python
Summary:        Python bindings for stp
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description python
Python bindings for stp library.

%prep
%setup -q

%build
%define __builder ninja
%cmake \
	-DBUILD_SHARED_LIBS:BOOL="on" \
	-DALSO_BUILD_STATIC_LIB:BOOL="off" \
	-DSTP_TIMESTAMPS:BOOL="off"
%make_jobs

%install
%cmake_install

%__install -d %{buildroot}/%{_docdir}/%{name}/example
%__install -m 644 -t %{buildroot}/%{_docdir}/%{name}/example examples/simple/*

%post -n libstp2_1 -p /sbin/ldconfig
%postun -n libstp2_1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS README.markdown LICENSE
%{_bindir}/stp*
%exclude %{_docdir}/%{name}/example/

%files -n libstp2_1
%{_libdir}/libstp.so.*

%files devel
%defattr(-,root,root)
%dir %{_includedir}/stp/
%{_includedir}/stp/*.h
%dir %{_libdir}/cmake/
%{_libdir}/libstp.so
%{_libdir}/cmake/STP/
%{_docdir}/%{name}/example/

%files python
%defattr(-,root,root)
%{python_sitelib}/*

%changelog
* Mon Feb 27 2017 jslaby@suse.com
- require only boost-program-options in tumbleweed
* Sat Feb 18 2017 jslaby@suse.com
- create libstp2_1 for library as required by policy
* Sun Nov 20 2016 jslaby@suse.com
- require minisat-devel and boost-devel in -devel
* Fri Nov 18 2016 jslaby@suse.com
- package also stp_simple, needed for cmake find_package
- Update to version 2.2+20161105:
  * Improve performance by creating fewer strings.
  * GitSHA1: really disable timestamp when requested
  * ASTNode rvalue reference assignment and copy constructor.
  * simplifier: use abort() after assert(false)
  * bug fix.
  * (1) fix building. (2) make index width / value width out of the base class. Saves 8 bytes in bvconst.
  * Might fix the issue described in #235. Missing dependencies.
  * oops. fix build.
* Fri Oct 28 2016 jslaby@suse.com
- update to 20161028
- remove simplifier-use-abort-instead-of-assert-false.patch
- remove GitSHA1-really-disable-timestamp-when-requested.patch
* Wed Oct 19 2016 jslaby@suse.com
- update to 20161005
- switch to ninja and %%cmake macros
- disable timestamps
- add simplifier-use-abort-instead-of-assert-false.patch
- add GitSHA1-really-disable-timestamp-when-requested.patch
* Fri Nov 27 2015 jslaby@suse.com
- update to 20151122
* Tue Nov  3 2015 jslaby@suse.com
- update to 20151030
- package AUTHORS and LICENSE
* Fri Sep  4 2015 jslaby@suse.com
- update to 20150904
  * remove: AST-simplify-FatalError-and-mark-as-noreturn.patch
* Fri Sep  4 2015 jslaby@suse.com
- remove: fix-no-return-in-nonvoid.patch
- add: AST-simplify-FatalError-and-mark-as-noreturn.patch
* Thu Sep  3 2015 jslaby@suse.com
- update to 20150828
  * drop one hunk from fix-no-return-in-nonvoid.patch
* Mon Apr 20 2015 jslaby@suse.com
- update to 20150418
  * remove: fix-install-paths.patch
  * remove: no-build-timestamps.patch
* Thu Apr 16 2015 jslaby@suse.com
- update to 20150415
  * drop one hunk from fix-no-return-in-nonvoid.patch
* Thu Oct 30 2014 jslaby@suse.com
- add no-build-timestamps.patch
* Mon Oct 20 2014 jslaby@suse.com
- update to 20140928
  * many fixes
  * remove-broken-functions.patch: remove, upstream
* Tue Apr 15 2014 jslaby@suse.com
- initial commit
